Module compile_cmd

Module compile_cmd 

Structs

CompileCommand
Compile the program and its secret execution trace into ACIR format

Functions

compile_workspace_full
Parse and compile the entire workspace, then report errors. This is the main entry point used by all other commands that need compilation.
parse_workspace
Parse all files in the workspace.