Structs
- Compile
Command - Compile the program and its secret execution trace into ACIR format
Functions
- compile_
workspace_ full - Parse and compile the entire workspace, then report errors. This is the main entry point used by all other commands that need compilation.
- parse_
workspace - Parse all files in the workspace.