pub fn compile_workspace_full(
workspace: &Workspace,
compile_options: &CompileOptions,
debug_compile_stdin: Option<String>,
) -> Result<(), CliError>Expand description
Parse and compile the entire workspace, then report errors. This is the main entry point used by all other commands that need compilation.